@@ -1,4 +1,4 @@
-test_that("FME computation correct", {
+testthat::test_that("FME computation correct", {
 
   library(mlr3verse)
   library(rpart)
@@ -17,10 +17,8 @@ test_that("FME computation correct", {
 
   fme.results = fme(model = tree,
                     data = df,
-                    target = "y",
-                    feature = "x",
-                    step.size = 2,
+                    features = list("x" = 2),
                     ep.method = "none")
 
-  expect_equal(fme.results$results$fme, fme.manual)
+  testthat::expect_equal(fme.results$results$fme, fme.manual)
 })
